==> JDFLibJ-2.1.7.11-sources.jar: org/cip4/jdflib/extensions/xjdfwalker/RemoveEmptyXJDF.java <==
/**
 * The CIP4 Software License, Version 1.0
 *
 * Copyright (c) 2001-2018 The International Cooperation for the Integration of
 * Processes in  Prepress, Press and Postpress (CIP4).  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        The International Cooperation for the Integration of
 *        Processes in  Prepress, Press and Postpress (www.cip4.org)"
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of
 *    Processes in  Prepress, Press and Postpress" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4",
 *    nor may "CIP4" appear in their name, without prior written
 *    permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For
 * details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR
 * THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the The International Cooperation for the Integration
 * of Processes in Prepress, Press and Postpress and was
 * originally based on software
 * copyright (c) 1999-2001, Heidelberger Druckmaschinen AG
 * copyright (c) 1999-2001, Agfa-Gevaert N.V.
 *
 * For more information on The International Cooperation for the
 * Integration of Processes in  Prepress, Press and Postpress , please see
 * <http://www.cip4.org/>.
 *
 *
 */
package org.cip4.jdflib.extensions.xjdfwalker;

import org.cip4.jdflib.core.AttributeName;
import org.cip4.jdflib.core.ElementName;
import org.cip4.jdflib.core.KElement;
import org.cip4.jdflib.core.VString;
import org.cip4.jdflib.elementwalker.RemoveEmpty;
import org.cip4.jdflib.extensions.XJDFConstants;
import org.cip4.jdflib.util.ContainerUtil;

/**
 *
 * @author rainer prosi
 *
 */
public class RemoveEmptyXJDF extends RemoveEmpty
{

	/**
	 *
	 */
	public RemoveEmptyXJDF()
	{
		super();
		addIgnoreElement(XJDFConstants.Header);
		addIgnoreElement(ElementName.CONTENTOBJECT);
		addIgnoreElement(ElementName.EXPOSEDMEDIA);
		addIgnoreElement(ElementName.MARKOBJECT);
		addIgnoreElement(ElementName.NODEINFO);
	}

	/**
	 * zapp me
	 *
	 * @author rainer prosi
	 *
	 */
	public class WalkResourceSet extends WalkElement
	{

		/**
		 * @see org.cip4.jdflib.elementwalker.BaseWalker#getElementNames()
		 */
		@Override
		public VString getElementNames()
		{
			return VString.getVString(XJDFConstants.ResourceSet, null);
		}

		/**
		 *
		 * @see org.cip4.jdflib.elementwalker.RemoveEmpty.WalkElement#getDummyAttributes()
		 */
		@Override
		protected VString getDummyAttributes()
		{
			final VString v = super.getDummyAttributes();
			v.add(AttributeName.COMBINEDPROCESSINDEX);
			v.add(AttributeName.NAME);
			v.add(AttributeName.USAGE);
			v.add(AttributeName.PROCESSUSAGE);
			v.add(AttributeName.ID);
			return v;
		}

	}

	/**
	 *
	 */
	public class WalkAuditResource extends WalkElement
	{

		/**
		 * @see org.cip4.jdflib.elementwalker.BaseWalker#getElementNames()
		 */
		@Override
		public VString getElementNames()
		{
			return VString.getVString(XJDFConstants.AuditResource, null);
		}

		/**
		 *
		 * @see org.cip4.jdflib.elementwalker.RemoveEmpty.WalkElement#hasRequiredChild(org.cip4.jdflib.core.KElement)
		 */
		@Override
		protected boolean hasRequiredChild(final KElement e1)
		{
			return e1.hasChildElement(ElementName.RESOURCEINFO, null);
		}

	}

	/**
	 *
	 */
	public class WalkResourceXJDF extends WalkElement
	{

		/**
		 * @see org.cip4.jdflib.elementwalker.BaseWalker#getElementNames()
		 */
		@Override
		public VString getElementNames()
		{
			return VString.getVString(XJDFConstants.Resource, null);
		}

		/**
		 * part elements are ignored
		 * @see org.cip4.jdflib.elementwalker.RemoveEmpty.WalkElement#hasChild(org.cip4.jdflib.core.KElement)
		 */
		@Override
		protected boolean hasChild(final KElement e1)
		{
			return ContainerUtil.getNonEmpty(e1.getChildrenIgnoreList(VString.getVString(ElementName.PART, null), true, null)) != null;
		}

	}
}

==> JDFLibJ-2.1.7.44-sources.jar: org/cip4/jdflib/extensions/xjdfwalker/RemoveEmptyXJDF.java <==
/**
 * The CIP4 Software License, Version 1.0
 *
 * Copyright (c) 2001-2022 The International Cooperation for the Integration of
 * Processes in  Prepress, Press and Postpress (CIP4).  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        The International Cooperation for the Integration of
 *        Processes in  Prepress, Press and Postpress (www.cip4.org)"
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of
 *    Processes in  Prepress, Press and Postpress" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4",
 *    nor may "CIP4" appear in their name, without prior written
 *    permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For
 * details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR
 * THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the The International Cooperation for the Integration
 * of Processes in Prepress, Press and Postpress and was
 * originally based on software
 * copyright (c) 1999-2001, Heidelberger Druckmaschinen AG
 * copyright (c) 1999-2001, Agfa-Gevaert N.V.
 *
 * For more information on The International Cooperation for the
 * Integration of Processes in  Prepress, Press and Postpress , please see
 * <http://www.cip4.org/>.
 *
 *
 */
package org.cip4.jdflib.extensions.xjdfwalker;

import org.cip4.jdflib.core.AttributeName;
import org.cip4.jdflib.core.ElementName;
import org.cip4.jdflib.core.KElement;
import org.cip4.jdflib.core.StringArray;
import org.cip4.jdflib.core.VString;
import org.cip4.jdflib.elementwalker.RemoveEmpty;
import org.cip4.jdflib.extensions.XJDFConstants;
import org.cip4.jdflib.util.ContainerUtil;

/**
 *
 * @author rainer prosi
 *
 */
public class RemoveEmptyXJDF extends RemoveEmpty
{

	/**
	 *
	 */
	public RemoveEmptyXJDF()
	{
		super();
		addIgnoreElement(XJDFConstants.Header);
		addIgnoreElement(ElementName.CONTENTOBJECT);
		addIgnoreElement(ElementName.EXPOSEDMEDIA);
		addIgnoreElement(ElementName.MARKOBJECT);
		addIgnoreElement(ElementName.NODEINFO);
	}

	/**
	 * zapp me
	 *
	 * @author rainer prosi
	 *
	 */
	public class WalkResourceSet extends WalkElement
	{

		/**
		 * @see org.cip4.jdflib.elementwalker.BaseWalker#getElementNames()
		 */
		@Override
		public VString getElementNames()
		{
			return VString.getVString(XJDFConstants.ResourceSet, null);
		}

		/**
		 *
		 * @see org.cip4.jdflib.elementwalker.RemoveEmpty.WalkElement#getDummyAttributes()
		 */
		@Override
		protected StringArray getDummyAttributes()
		{
			final StringArray v = super.getDummyAttributes();
			v.add(AttributeName.COMBINEDPROCESSINDEX);
			v.add(AttributeName.NAME);
			v.add(AttributeName.USAGE);
			v.add(AttributeName.PROCESSUSAGE);
			v.add(AttributeName.STATUS);
			return v;
		}

	}

	/**
	 *
	 */
	public class WalkAuditResource extends WalkElement
	{

		/**
		 * @see org.cip4.jdflib.elementwalker.BaseWalker#getElementNames()
		 */
		@Override
		public VString getElementNames()
		{
			return VString.getVString(XJDFConstants.AuditResource, null);
		}

		/**
		 *
		 * @see org.cip4.jdflib.elementwalker.RemoveEmpty.WalkElement#hasRequiredChild(org.cip4.jdflib.core.KElement)
		 */
		@Override
		protected boolean hasRequiredChild(final KElement e1)
		{
			return e1.hasChildElement(ElementName.RESOURCEINFO, null);
		}

	}

	/**
	 *
	 */
	public class WalkResourceXJDF extends WalkElement
	{

		/**
		 * @see org.cip4.jdflib.elementwalker.BaseWalker#getElementNames()
		 */
		@Override
		public VString getElementNames()
		{
			return VString.getVString(XJDFConstants.Resource, null);
		}

		/**
		 * part elements are ignored
		 * 
		 * @see org.cip4.jdflib.elementwalker.RemoveEmpty.WalkElement#hasChild(org.cip4.jdflib.core.KElement)
		 */
		@Override
		protected boolean hasChild(final KElement e1)
		{
			return ContainerUtil.getNonEmpty(e1.getChildrenIgnoreList(VString.getVString(ElementName.PART, null), true, null)) != null;
		}

		/**
		 *
		 * @see org.cip4.jdflib.elementwalker.RemoveEmpty.WalkElement#getDummyAttributes()
		 */
		@Override
		protected StringArray getDummyAttributes()
		{
			final StringArray v = super.getDummyAttributes();
			v.add(AttributeName.STATUS);
			return v;
		}

	}
}
